summaryrefslogtreecommitdiffstats
path: root/shemov.cpp
diff options
context:
space:
mode:
authorArno <am@disconnect.de>2010-07-18 14:42:26 +0200
committerArno <am@disconnect.de>2010-07-18 14:42:26 +0200
commita59ac6eb3cebdd4e3f41552c21f14165203c1ab2 (patch)
tree0ff0cec23fce7b08f02bc9acffa4adda02b906c2 /shemov.cpp
parent6d00ae1d57ed37a8d3d6d35181cb6b155dd7801c (diff)
downloadSheMov-a59ac6eb3cebdd4e3f41552c21f14165203c1ab2.tar.gz
SheMov-a59ac6eb3cebdd4e3f41552c21f14165203c1ab2.tar.bz2
SheMov-a59ac6eb3cebdd4e3f41552c21f14165203c1ab2.zip
Implemented add covers
Finally we can add covers to already existsing series. Seems to work, but I encountered a crash when merging series while testing... Unfortunately I don't know the cause.
Diffstat (limited to 'shemov.cpp')
-rw-r--r--shemov.cpp8
1 files changed, 7 insertions, 1 deletions
diff --git a/shemov.cpp b/shemov.cpp
index 4d6302d..71a6c96 100644
--- a/shemov.cpp
+++ b/shemov.cpp
@@ -379,7 +379,7 @@ void SheMov::createActions(){
mStatisticsA = new QAction(tr("Some statistics..."), this);
connect(mStatisticsA, SIGNAL(triggered()), this, SLOT(showStatistics()));
//Tree context menu
mNewSeriesA = new QAction(tr("New series..."), this);
connect(mNewSeriesA, SIGNAL(triggered()), mATree->seriesWidget(), SLOT(newSeries()));
mDeleteFromSeriesA = new QAction(tr("Delete entries..."), this);
@@ -394,6 +394,8 @@ void SheMov::createActions(){
connect(mExpandCurrentA, SIGNAL(triggered()), mATree->seriesWidget(), SLOT(expandCurrent()));
mNewMovieWizardA = new QAction(tr("Archive movie..."), this);
connect(mNewMovieWizardA, SIGNAL(triggered()), this, SLOT(newMovieWizard()));
+ mAddCoverA = new QAction(tr("Add cover..."), this);
+ connect(mAddCoverA, SIGNAL(triggered()), mATree->seriesWidget(), SLOT(addCover()));
//Tree view menu
mViewTreeGroup = new QActionGroup(this);
@@ -565,6 +567,10 @@ void SheMov::createMenus(){
mATree->seriesWidget()->seriesTree()->addAction(mExpandCurrentA);
mATree->seriesWidget()->seriesTree()->addAction(mExpandAllSeriesA);
mATree->seriesWidget()->seriesTree()->addAction(mCollapseAllSeriesA);
+ QAction *sep12 = new QAction(this);
+ sep12->setSeparator(true);
+ mATree->seriesWidget()->seriesTree()->addAction(sep12);
+ mATree->seriesWidget()->seriesTree()->addAction(mAddCoverA);
//ArchiveTreeView fileWidget context menu
mATree->filesWidget()->filesTree()->addAction(mMoveToBurnA);
@@ -379,7 +379,7 @@ void SheMov::createActions(){
mStatisticsA = new QAction(tr("Some statistics..."), this);
connect(mStatisticsA, SIGNAL(triggered()), this, SLOT(showStatistics()));
- //Tree context menu
+ //Tree series context menu
mNewSeriesA = new QAction(tr("New series..."), this);
connect(mNewSeriesA, SIGNAL(triggered()), mATree->seriesWidget(), SLOT(newSeries()));